searchData={"content_type":"text/markdown","items":[{"doc":"Provides HTTP request functionality for the ExMtnMomo library.\n\nThis module handles the low-level HTTP operations needed to communicate with\nthe MTN Mobile Money API, including:\n\n* Making POST, PUT, and GET requests\n* Handling responses and errors\n* Parsing JSON responses\n\nThis module is used internally by the ExMtnMomo library and typically\ndoesn't need to be used directly by library users.","ref":"ExMtnMomo.HttpRequest.html","title":"ExMtnMomo.HttpRequest","type":"module"},{"doc":"Sends a GET request to the specified URL.","ref":"ExMtnMomo.HttpRequest.html#get/3","title":"ExMtnMomo.HttpRequest.get/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `attrs` - Query parameters to append to the URL (optional)\n* `headers` - Custom headers to include with the request (optional)","ref":"ExMtnMomo.HttpRequest.html#get/3-parameters","title":"Parameters - ExMtnMomo.HttpRequest.get/3","type":"function"},{"doc":"* The response from the HTTP client (HTTPoison)","ref":"ExMtnMomo.HttpRequest.html#get/3-returns","title":"Returns - ExMtnMomo.HttpRequest.get/3","type":"function"},{"doc":"iex> ExMtnMomo.HttpRequest.get(\"https://api.example.com/endpoint\", %{filter: \"value\"}, [{\"X-Custom\", \"Header\"}])\n    {:ok, %HTTPoison.Response{...}}","ref":"ExMtnMomo.HttpRequest.html#get/3-examples","title":"Examples - ExMtnMomo.HttpRequest.get/3","type":"function"},{"doc":"Handles HTTP responses and standardizes the return format.\n\nThis function processes the raw response from HTTPoison and converts it\ninto a more usable format for the library.","ref":"ExMtnMomo.HttpRequest.html#handle_response/1","title":"ExMtnMomo.HttpRequest.handle_response/1","type":"function"},{"doc":"* `response` - The response tuple from an HTTP request","ref":"ExMtnMomo.HttpRequest.html#handle_response/1-parameters","title":"Parameters - ExMtnMomo.HttpRequest.handle_response/1","type":"function"},{"doc":"* `{:ok, body}` - For successful responses, with body parsed from JSON\n* `{:error, message}` - For error responses, with error message","ref":"ExMtnMomo.HttpRequest.html#handle_response/1-returns","title":"Returns - ExMtnMomo.HttpRequest.handle_response/1","type":"function"},{"doc":"* 200, 201, 202 - Success responses\n* 400, 401, 405, 408, 409, 422, 500, 503 - Error responses with specific handling","ref":"ExMtnMomo.HttpRequest.html#handle_response/1-response-status-codes","title":"Response Status Codes - ExMtnMomo.HttpRequest.handle_response/1","type":"function"},{"doc":"Creates standard headers for HTTP requests with an authentication token.","ref":"ExMtnMomo.HttpRequest.html#header/1","title":"ExMtnMomo.HttpRequest.header/1","type":"function"},{"doc":"* `key` - The authentication token or key to include in the Authorization header","ref":"ExMtnMomo.HttpRequest.html#header/1-parameters","title":"Parameters - ExMtnMomo.HttpRequest.header/1","type":"function"},{"doc":"* A list of HTTP headers with Content-Type, Origin and Authorization","ref":"ExMtnMomo.HttpRequest.html#header/1-returns","title":"Returns - ExMtnMomo.HttpRequest.header/1","type":"function"},{"doc":"iex> ExMtnMomo.HttpRequest.header(\"eyJ0eXAi...\")\n    [\n      {\"Content-Type\", \"application/json\"},\n      {\"Origin\", \"*\"},\n      {\"Authorization\", \"Bearer eyJ0eXAi...\"},\n    ]","ref":"ExMtnMomo.HttpRequest.html#header/1-examples","title":"Examples - ExMtnMomo.HttpRequest.header/1","type":"function"},{"doc":"Sends a POST request to the specified URL.","ref":"ExMtnMomo.HttpRequest.html#post/3","title":"ExMtnMomo.HttpRequest.post/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `body` - The request payload, will be encoded as JSON\n* `headers` - Custom headers to include with the request (optional)","ref":"ExMtnMomo.HttpRequest.html#post/3-parameters","title":"Parameters - ExMtnMomo.HttpRequest.post/3","type":"function"},{"doc":"* The response from the HTTP client (HTTPoison)","ref":"ExMtnMomo.HttpRequest.html#post/3-returns","title":"Returns - ExMtnMomo.HttpRequest.post/3","type":"function"},{"doc":"iex> ExMtnMomo.HttpRequest.post(\"https://api.example.com/endpoint\", %{key: \"value\"}, [{\"X-Custom\", \"Header\"}])\n    {:ok, %HTTPoison.Response{...}}","ref":"ExMtnMomo.HttpRequest.html#post/3-examples","title":"Examples - ExMtnMomo.HttpRequest.post/3","type":"function"},{"doc":"Sends a PUT request to the specified URL.","ref":"ExMtnMomo.HttpRequest.html#put/3","title":"ExMtnMomo.HttpRequest.put/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `body` - The request payload, will be encoded as JSON\n* `headers` - Custom headers to include with the request (optional)","ref":"ExMtnMomo.HttpRequest.html#put/3-parameters","title":"Parameters - ExMtnMomo.HttpRequest.put/3","type":"function"},{"doc":"* The response from the HTTP client (HTTPoison)","ref":"ExMtnMomo.HttpRequest.html#put/3-returns","title":"Returns - ExMtnMomo.HttpRequest.put/3","type":"function"},{"doc":"iex> ExMtnMomo.HttpRequest.put(\"https://api.example.com/endpoint\", %{key: \"value\"}, [{\"X-Custom\", \"Header\"}])\n    {:ok, %HTTPoison.Response{...}}","ref":"ExMtnMomo.HttpRequest.html#put/3-examples","title":"Examples - ExMtnMomo.HttpRequest.put/3","type":"function"},{"doc":"Provides utility functions and configuration handling for the ExMtnMomo library.\n\nThis module handles:\n\n* Extracting configuration values with fallbacks\n* Creating authentication headers\n* Sending HTTP requests through the HttpRequest module\n\nMost of these functions are used internally by the library and typically\ndon't need to be called directly by library users.","ref":"ExMtnMomo.Util.html","title":"ExMtnMomo.Util","type":"module"},{"doc":"Creates a Basic Authentication header value from a username and password.","ref":"ExMtnMomo.Util.html#basic_auth/2","title":"ExMtnMomo.Util.basic_auth/2","type":"function"},{"doc":"* `username` - The username for authentication\n* `password` - The password or API key for authentication","ref":"ExMtnMomo.Util.html#basic_auth/2-parameters","title":"Parameters - ExMtnMomo.Util.basic_auth/2","type":"function"},{"doc":"* The Basic Auth header value in the format \"Basic {base64-encoded string}\"","ref":"ExMtnMomo.Util.html#basic_auth/2-returns","title":"Returns - ExMtnMomo.Util.basic_auth/2","type":"function"},{"doc":"iex> ExMtnMomo.Util.basic_auth(\"user123\", \"pass456\")\n    \"Basic dXNlcjEyMzpwYXNzNDU2\"","ref":"ExMtnMomo.Util.html#basic_auth/2-examples","title":"Examples - ExMtnMomo.Util.basic_auth/2","type":"function"},{"doc":"Creates a Basic Authentication header value for collection API operations.","ref":"ExMtnMomo.Util.html#collection_auth/1","title":"ExMtnMomo.Util.collection_auth/1","type":"function"},{"doc":"* `options` - Keyword list of options (optional)","ref":"ExMtnMomo.Util.html#collection_auth/1-parameters","title":"Parameters - ExMtnMomo.Util.collection_auth/1","type":"function"},{"doc":"* The Basic Auth header value for collection operations","ref":"ExMtnMomo.Util.html#collection_auth/1-returns","title":"Returns - ExMtnMomo.Util.collection_auth/1","type":"function"},{"doc":"iex> ExMtnMomo.Util.collection_auth()\n    \"Basic dXNlcmlkOmFwaWtleQ==\"","ref":"ExMtnMomo.Util.html#collection_auth/1-examples","title":"Examples - ExMtnMomo.Util.collection_auth/1","type":"function"},{"doc":"Creates a Basic Authentication header value for disbursement API operations.","ref":"ExMtnMomo.Util.html#disbursement_auth/1","title":"ExMtnMomo.Util.disbursement_auth/1","type":"function"},{"doc":"* `options` - Keyword list of options (optional)","ref":"ExMtnMomo.Util.html#disbursement_auth/1-parameters","title":"Parameters - ExMtnMomo.Util.disbursement_auth/1","type":"function"},{"doc":"* The Basic Auth header value for disbursement operations","ref":"ExMtnMomo.Util.html#disbursement_auth/1-returns","title":"Returns - ExMtnMomo.Util.disbursement_auth/1","type":"function"},{"doc":"iex> ExMtnMomo.Util.disbursement_auth()\n    \"Basic dXNlcmlkOmFwaWtleQ==\"","ref":"ExMtnMomo.Util.html#disbursement_auth/1-examples","title":"Examples - ExMtnMomo.Util.disbursement_auth/1","type":"function"},{"doc":"Extracts the base URL from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_base_url/1","title":"ExMtnMomo.Util.extract_base_url/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :base_url (optional)","ref":"ExMtnMomo.Util.html#extract_base_url/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_base_url/1","type":"function"},{"doc":"* The base URL for API requests","ref":"ExMtnMomo.Util.html#extract_base_url/1-returns","title":"Returns - ExMtnMomo.Util.extract_base_url/1","type":"function"},{"doc":"iex> ExMtnMomo.Util.extract_base_url()\n    \"https://sandbox.momodeveloper.mtn.com\"\n\n    iex> ExMtnMomo.Util.extract_base_url(base_url: \"https://custom.api.url\")\n    \"https://custom.api.url\"","ref":"ExMtnMomo.Util.html#extract_base_url/1-examples","title":"Examples - ExMtnMomo.Util.extract_base_url/1","type":"function"},{"doc":"Extracts the collection API key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_collection_api_key/1","title":"ExMtnMomo.Util.extract_collection_api_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :api_key (optional)","ref":"ExMtnMomo.Util.html#extract_collection_api_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_collection_api_key/1","type":"function"},{"doc":"* The collection API key","ref":"ExMtnMomo.Util.html#extract_collection_api_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_collection_api_key/1","type":"function"},{"doc":"Extracts the collection primary key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_collection_primary_key/1","title":"ExMtnMomo.Util.extract_collection_primary_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :primary_key (optional)","ref":"ExMtnMomo.Util.html#extract_collection_primary_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_collection_primary_key/1","type":"function"},{"doc":"* The collection primary key","ref":"ExMtnMomo.Util.html#extract_collection_primary_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_collection_primary_key/1","type":"function"},{"doc":"Extracts the collection secondary key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_collection_secondary_key/1","title":"ExMtnMomo.Util.extract_collection_secondary_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :secondary_key (optional)","ref":"ExMtnMomo.Util.html#extract_collection_secondary_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_collection_secondary_key/1","type":"function"},{"doc":"* The collection secondary key","ref":"ExMtnMomo.Util.html#extract_collection_secondary_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_collection_secondary_key/1","type":"function"},{"doc":"Extracts the collection user ID from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_collection_user_id/1","title":"ExMtnMomo.Util.extract_collection_user_id/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :user_id (optional)","ref":"ExMtnMomo.Util.html#extract_collection_user_id/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_collection_user_id/1","type":"function"},{"doc":"* The collection user ID","ref":"ExMtnMomo.Util.html#extract_collection_user_id/1-returns","title":"Returns - ExMtnMomo.Util.extract_collection_user_id/1","type":"function"},{"doc":"Extracts the disbursement API key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_disbursement_api_key/1","title":"ExMtnMomo.Util.extract_disbursement_api_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :api_key (optional)","ref":"ExMtnMomo.Util.html#extract_disbursement_api_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_disbursement_api_key/1","type":"function"},{"doc":"* The disbursement API key","ref":"ExMtnMomo.Util.html#extract_disbursement_api_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_disbursement_api_key/1","type":"function"},{"doc":"Extracts the disbursement primary key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_disbursement_primary_key/1","title":"ExMtnMomo.Util.extract_disbursement_primary_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :primary_key (optional)","ref":"ExMtnMomo.Util.html#extract_disbursement_primary_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_disbursement_primary_key/1","type":"function"},{"doc":"* The disbursement primary key","ref":"ExMtnMomo.Util.html#extract_disbursement_primary_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_disbursement_primary_key/1","type":"function"},{"doc":"Extracts the disbursement secondary key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_disbursement_secondary_key/1","title":"ExMtnMomo.Util.extract_disbursement_secondary_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :secondary_key (optional)","ref":"ExMtnMomo.Util.html#extract_disbursement_secondary_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_disbursement_secondary_key/1","type":"function"},{"doc":"* The disbursement secondary key","ref":"ExMtnMomo.Util.html#extract_disbursement_secondary_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_disbursement_secondary_key/1","type":"function"},{"doc":"Extracts the disbursement user ID from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_disbursement_user_id/1","title":"ExMtnMomo.Util.extract_disbursement_user_id/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :user_id (optional)","ref":"ExMtnMomo.Util.html#extract_disbursement_user_id/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_disbursement_user_id/1","type":"function"},{"doc":"* The disbursement user ID","ref":"ExMtnMomo.Util.html#extract_disbursement_user_id/1-returns","title":"Returns - ExMtnMomo.Util.extract_disbursement_user_id/1","type":"function"},{"doc":"Extracts the sandbox key from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_sand_box_key/1","title":"ExMtnMomo.Util.extract_sand_box_key/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :sandbox_key (optional)","ref":"ExMtnMomo.Util.html#extract_sand_box_key/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_sand_box_key/1","type":"function"},{"doc":"* The sandbox key for authentication","ref":"ExMtnMomo.Util.html#extract_sand_box_key/1-returns","title":"Returns - ExMtnMomo.Util.extract_sand_box_key/1","type":"function"},{"doc":"Extracts the target environment from options or application configuration.","ref":"ExMtnMomo.Util.html#extract_x_target_environment/1","title":"ExMtnMomo.Util.extract_x_target_environment/1","type":"function"},{"doc":"* `options` - Keyword list of options that may include :x_target_environment (optional)","ref":"ExMtnMomo.Util.html#extract_x_target_environment/1-parameters","title":"Parameters - ExMtnMomo.Util.extract_x_target_environment/1","type":"function"},{"doc":"* The target environment (e.g., \"sandbox\", \"mtnzambia\")","ref":"ExMtnMomo.Util.html#extract_x_target_environment/1-returns","title":"Returns - ExMtnMomo.Util.extract_x_target_environment/1","type":"function"},{"doc":"iex> ExMtnMomo.Util.extract_x_target_environment()\n    \"sandbox\"\n\n    iex> ExMtnMomo.Util.extract_x_target_environment(x_target_environment: \"mtnzambia\")\n    \"mtnzambia\"","ref":"ExMtnMomo.Util.html#extract_x_target_environment/1-examples","title":"Examples - ExMtnMomo.Util.extract_x_target_environment/1","type":"function"},{"doc":"Sends a GET request to the specified URL.","ref":"ExMtnMomo.Util.html#send_get/3","title":"ExMtnMomo.Util.send_get/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `attrs` - Query parameters to append to the URL\n* `header` - HTTP headers to include with the request","ref":"ExMtnMomo.Util.html#send_get/3-parameters","title":"Parameters - ExMtnMomo.Util.send_get/3","type":"function"},{"doc":"* `{:ok, response_body}` on success\n* `{:error, error_message}` on failure","ref":"ExMtnMomo.Util.html#send_get/3-returns","title":"Returns - ExMtnMomo.Util.send_get/3","type":"function"},{"doc":"Sends a POST request to the specified URL.","ref":"ExMtnMomo.Util.html#send_post/3","title":"ExMtnMomo.Util.send_post/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `attrs` - Request body payload\n* `headers` - HTTP headers to include with the request","ref":"ExMtnMomo.Util.html#send_post/3-parameters","title":"Parameters - ExMtnMomo.Util.send_post/3","type":"function"},{"doc":"* `{:ok, response_body}` on success\n* `{:error, error_message}` on failure","ref":"ExMtnMomo.Util.html#send_post/3-returns","title":"Returns - ExMtnMomo.Util.send_post/3","type":"function"},{"doc":"Sends a PUT request to the specified URL.","ref":"ExMtnMomo.Util.html#send_put/3","title":"ExMtnMomo.Util.send_put/3","type":"function"},{"doc":"* `url` - The URL to send the request to\n* `attrs` - Request body payload\n* `encrypt_api_key` - API key for authentication","ref":"ExMtnMomo.Util.html#send_put/3-parameters","title":"Parameters - ExMtnMomo.Util.send_put/3","type":"function"},{"doc":"* `{:ok, response_body}` on success\n* `{:error, error_message}` on failure","ref":"ExMtnMomo.Util.html#send_put/3-returns","title":"Returns - ExMtnMomo.Util.send_put/3","type":"function"},{"doc":"ExMtnMomo is an Elixir library for interacting with the MTN Mobile Money API.\n\nThis library provides a simple interface to MTN Mobile Money's Sandbox, Collection,\nand Disbursement APIs, making it easy to integrate MTN Mobile Money into your\nElixir applications.","ref":"ExMtnMomo.html","title":"ExMtnMomo","type":"module"},{"doc":"* Sandbox API for testing and development\n* Collection API for receiving payments\n* Disbursement API for sending payments\n* Comprehensive error handling\n* Configurable environment settings","ref":"ExMtnMomo.html#module-features","title":"Features - ExMtnMomo","type":"module"},{"doc":"This library is organized into three main modules:\n\n* `ExMtnMomo.Sandbox` - Functions for setting up and testing in the sandbox environment\n* `ExMtnMomo.Collection` - Functions for receiving payments from customers\n* `ExMtnMomo.Disbursements` - Functions for sending payments to customers","ref":"ExMtnMomo.html#module-module-overview","title":"Module Overview - ExMtnMomo","type":"module"},{"doc":"The following configuration options can be set in your `config.exs` file:","ref":"ExMtnMomo.html#module-configuration-options","title":"Configuration Options - ExMtnMomo","type":"module"},{"doc":"* `:base_url` - The base URL for the MTN Mobile Money API\n  * Default for sandbox: `\"https://sandbox.momodeveloper.mtn.com\"`\n  * Production: URL provided by MTN for your specific region\n\n* `:x_target_environment` - The target environment for API requests\n  * Options: `\"sandbox\"` for testing, or a specific production environment like `\"mtnzambia\"`\n  * Default: `\"sandbox\"`\n\n* `:sandbox_key` - The API key for sandbox operations\n  * This can be either your primary or secondary key provided by MTN\n  * Used only for sandbox-specific operations","ref":"ExMtnMomo.html#module-global-configuration-options","title":"Global Configuration Options - ExMtnMomo","type":"module"},{"doc":"Disbursement credentials are configured as a map under the `:disbursement` key:\n\n```elixir\nconfig :ex_mtn_momo,\n  disbursement: %{\n    secondary_key: \"your_secondary_key\",  # Subscription key for disbursement API\n    primary_key: \"your_primary_key\",      # Alternative subscription key\n    user_id: \"your_user_id\",              # User ID for authentication\n    api_key: \"your_api_key\"               # API key for authentication\n  }\n```","ref":"ExMtnMomo.html#module-disbursement-configuration-options","title":"Disbursement Configuration Options - ExMtnMomo","type":"module"},{"doc":"Collection credentials are configured as a map under the `:collection` key:\n\n```elixir\nconfig :ex_mtn_momo,\n  collection: %{\n    secondary_key: \"your_secondary_key\",  # Subscription key for collection API\n    primary_key: \"your_primary_key\",      # Alternative subscription key\n    user_id: \"your_user_id\",              # User ID for authentication\n    api_key: \"your_api_key\"               # API key for authentication\n  }\n```","ref":"ExMtnMomo.html#module-collection-configuration-options","title":"Collection Configuration Options - ExMtnMomo","type":"module"},{"doc":"Most functions in this library accept an `options` parameter that can be used to override\nconfiguration values at runtime. The following options are supported:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:primary_key` - Override the primary key to use for authentication\n* `:user_id` - Override the user ID for authentication\n* `:api_key` - Override the API key for authentication\n* `:x_target_environment` - Override the target environment\n* `:sandbox_key` - Override the sandbox key (for sandbox operations only)\n\nExample:\n\n```elixir\n# Override the base URL and target environment for a specific request\noptions = [\n  base_url: \"https://alternative-api.example.com\",\n  x_target_environment: \"production\"\n]\n\nExMtnMomo.collect_funds(payment_details, UUID.uuid4(), options)\n```","ref":"ExMtnMomo.html#module-runtime-options","title":"Runtime Options - ExMtnMomo","type":"module"},{"doc":"First, configure your MTN MoMo API credentials in your `config.exs` file:\n\n```elixir\nconfig :ex_mtn_momo,\n  base_url: \"https://sandbox.momodeveloper.mtn.com\",\n  x_target_environment: \"sandbox\", # mtnzambia | sandbox\n  disbursement: %{\n    secondary_key: \"your_secondary_key\",\n    primary_key: \"your_primary_key\",\n    user_id: \"your_user_id\",\n    api_key: \"your_api_key\"\n  },\n  collection: %{\n    secondary_key: \"your_secondary_key\",\n    primary_key: \"your_primary_key\",\n    user_id: \"your_user_id\",\n    api_key: \"your_api_key\"\n  }\n```\n\nThen, you can start using the library in your application.\n\nSee the documentation for `ExMtnMomo.Sandbox`, `ExMtnMomo.Collection`, and\n`ExMtnMomo.Disbursements` for specific usage examples.","ref":"ExMtnMomo.html#module-getting-started","title":"Getting Started - ExMtnMomo","type":"module"},{"doc":"Initiates a payment collection request.\n\nThis function serves as a simplified wrapper around the Collection API, handling\ntoken creation and payment request in a single function call.","ref":"ExMtnMomo.html#collect_funds/3","title":"ExMtnMomo.collect_funds/3","type":"function"},{"doc":"* `attrs` - A map containing payment details\n* `x_reference_id` - A UUID v4 string as the reference ID (optional, generated automatically if not provided)\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.html#collect_funds/3-parameters","title":"Parameters - ExMtnMomo.collect_funds/3","type":"function"},{"doc":"The `attrs` map should include the following keys:\n\n* `\"amount\"` - The payment amount\n* `\"currency\"` - The currency code (e.g., \"EUR\", \"USD\")\n* `\"externalId\"` - Your system's transaction ID\n* `\"payer\"` - A map containing payer information:\n  * `\"partyIdType\"` - The type of identifier (usually \"MSISDN\")\n  * `\"partyId\"` - The mobile number of the payer\n* `\"payerMessage\"` - Message shown to the payer\n* `\"payeeNote\"` - Note for the payee's records","ref":"ExMtnMomo.html#collect_funds/3-payment-details","title":"Payment Details - ExMtnMomo.collect_funds/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.html#collect_funds/3-options","title":"Options - ExMtnMomo.collect_funds/3","type":"function"},{"doc":"* `{:ok, result}` on success, with result containing:\n  * `\"x_reference_id\"` - The reference ID for the payment\n  * `\"status\"` - The status of the payment request (initially \"pending\")\n  * `\"message\"` - A status message\n* `{:error, reason}` on failure","ref":"ExMtnMomo.html#collect_funds/3-returns","title":"Returns - ExMtnMomo.collect_funds/3","type":"function"},{"doc":"iex> payment_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payer\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Payment for products\",\n    ...>   \"payeeNote\" => \"Payment received\"\n    ...> }\n    iex> ExMtnMomo.collect_funds(payment_details)\n    {:ok, %{\n       \"x_reference_id\" => \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\",\n       \"status\" => \"pending\",\n       \"message\" => \"Request to pay has been sent\"\n      }}","ref":"ExMtnMomo.html#collect_funds/3-examples","title":"Examples - ExMtnMomo.collect_funds/3","type":"function"},{"doc":"Checks the status of a payment collection request.\n\nThis function serves as a simplified wrapper around the Collection API's transaction\nstatus endpoint, handling token creation and status check in a single function call.","ref":"ExMtnMomo.html#collections_check_transaction_status/2","title":"ExMtnMomo.collections_check_transaction_status/2","type":"function"},{"doc":"* `reference_id` - The reference ID of the payment request\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.html#collections_check_transaction_status/2-parameters","title":"Parameters - ExMtnMomo.collections_check_transaction_status/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.html#collections_check_transaction_status/2-options","title":"Options - ExMtnMomo.collections_check_transaction_status/2","type":"function"},{"doc":"* `{:ok, status_details}` on success, with status_details containing:\n  * `\"amount\"` - The payment amount\n  * `\"currency\"` - The currency code\n  * `\"externalId\"` - Your system's transaction ID\n  * `\"financialTransactionId\"` - The MTN transaction ID\n  * `\"payeeNote\"` - Note for the payee's records\n  * `\"payer\"` - Information about the payer\n  * `\"payerMessage\"` - Message shown to the payer\n  * `\"status\"` - The status of the payment (e.g., \"SUCCESSFUL\", \"PENDING\", \"FAILED\")\n* `{:error, reason}` on failure","ref":"ExMtnMomo.html#collections_check_transaction_status/2-returns","title":"Returns - ExMtnMomo.collections_check_transaction_status/2","type":"function"},{"doc":"iex> ExMtnMomo.collections_check_transaction_status(\"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\")\n    {:ok, %{\n      \"amount\" => \"1000\",\n      \"currency\" => \"EUR\",\n      \"externalId\" => \"123456789\",\n      \"financialTransactionId\" => \"1308275464\",\n      \"payeeNote\" => \"Payment received\",\n      \"payer\" => %{\"partyId\" => \"256771234567\", \"partyIdType\" => \"MSISDN\"},\n      \"payerMessage\" => \"Payment for products\",\n      \"status\" => \"SUCCESSFUL\"\n      }}","ref":"ExMtnMomo.html#collections_check_transaction_status/2-examples","title":"Examples - ExMtnMomo.collections_check_transaction_status/2","type":"function"},{"doc":"Creates a sandbox user with all required credentials.\n\nThis helper function simplifies the process of setting up a sandbox user by\ngenerating a UUID, creating the user, retrieving the API key, and getting the user details\nin a single function call.","ref":"ExMtnMomo.html#create_sandbox_user/2","title":"ExMtnMomo.create_sandbox_user/2","type":"function"},{"doc":"* `callback_url` - URL to receive API callbacks (defaults to \"https://webhook.site\")\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.html#create_sandbox_user/2-parameters","title":"Parameters - ExMtnMomo.create_sandbox_user/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.html#create_sandbox_user/2-options","title":"Options - ExMtnMomo.create_sandbox_user/2","type":"function"},{"doc":"* `{:ok, user_details}` on success, with user_details containing:\n  * `\"user_id\"` - The UUID of the created user\n  * `\"api_key\"` - The API key for the user\n  * `\"providerCallbackHost\"` - The callback URL\n  * `\"targetEnvironment\"` - The target environment\n* `{:error, reason}` on failure","ref":"ExMtnMomo.html#create_sandbox_user/2-returns","title":"Returns - ExMtnMomo.create_sandbox_user/2","type":"function"},{"doc":"iex> ExMtnMomo.create_sandbox_user()\n    {:ok, %{\n      \"api_key\" => \"6418abf0507b4829a7ded11ca8f67cd7\",\n      \"providerCallbackHost\" => \"https://webhook.site\",\n      \"targetEnvironment\" => \"sandbox\",\n      \"user_id\" => \"3d6df852-7be6-4870-be57-b784446a885c\"\n      }}","ref":"ExMtnMomo.html#create_sandbox_user/2-examples","title":"Examples - ExMtnMomo.create_sandbox_user/2","type":"function"},{"doc":"Initiates a funds disbursement (payment to a customer).\n\nThis function serves as a simplified wrapper around the Disbursements API, handling\ntoken creation and funds transfer in a single function call.","ref":"ExMtnMomo.html#disburse_funds/3","title":"ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"* `attrs` - A map containing disbursement details\n* `reference_id` - A UUID v4 string as the reference ID (optional, generated automatically if not provided)\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.html#disburse_funds/3-parameters","title":"Parameters - ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"The `attrs` map should include the following keys:\n\n* `\"amount\"` - The payment amount\n* `\"currency\"` - The currency code (e.g., \"EUR\", \"USD\")\n* `\"externalId\"` - Your system's transaction ID\n* `\"payer\"` - A map containing payer information:\n  * `\"partyIdType\"` - The type of identifier (usually \"MSISDN\")\n  * `\"partyId\"` - The mobile number of the payer\n* `\"payerMessage\"` - Message shown to the payer\n* `\"payeeNote\"` - Note for the payee's records","ref":"ExMtnMomo.html#disburse_funds/3-disbursement-details","title":"Disbursement Details - ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.html#disburse_funds/3-options","title":"Options - ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.html#disburse_funds/3-returns","title":"Returns - ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"iex> attrs = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"1234564789\",\n    ...>   \"payer\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Payment for products\",\n    ...>   \"payeeNote\" => \"Payment received\"\n    ...> }\n    iex> ExMtnMomo.disburse_funds(attrs)\n    {:ok, %{}}","ref":"ExMtnMomo.html#disburse_funds/3-examples","title":"Examples - ExMtnMomo.disburse_funds/3","type":"function"},{"doc":"Checks the status of a disbursement transaction.\n\nThis function serves as a simplified wrapper around the Disbursements API's transaction\nstatus endpoint, handling token creation and status check in a single function call.","ref":"ExMtnMomo.html#disbursements_check_transaction_status/2","title":"ExMtnMomo.disbursements_check_transaction_status/2","type":"function"},{"doc":"* `reference_id` - The reference ID of the disbursement request\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.html#disbursements_check_transaction_status/2-parameters","title":"Parameters - ExMtnMomo.disbursements_check_transaction_status/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.html#disbursements_check_transaction_status/2-options","title":"Options - ExMtnMomo.disbursements_check_transaction_status/2","type":"function"},{"doc":"* `{:ok, status_details}` on success, with status_details typically containing:\n  * `\"amount\"` - The payment amount\n  * `\"currency\"` - The currency code\n  * `\"externalId\"` - Your system's transaction ID\n  * `\"financialTransactionId\"` - The MTN transaction ID\n  * `\"payeeNote\"` - Note for the payee's records\n  * `\"payee\"` - Information about the payee\n  * `\"status\"` - The status of the payment (e.g., \"SUCCESSFUL\", \"PENDING\", \"FAILED\")\n* `{:error, reason}` on failure","ref":"ExMtnMomo.html#disbursements_check_transaction_status/2-returns","title":"Returns - ExMtnMomo.disbursements_check_transaction_status/2","type":"function"},{"doc":"iex> ExMtnMomo.disbursements_check_transaction_status(\"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\")\n    {:ok, %{\n      \"amount\" => \"1000\",\n      \"currency\" => \"EUR\",\n      \"externalId\" => \"123456789\",\n      \"financialTransactionId\" => \"1308275464\",\n      \"payeeNote\" => \"Payment received\",\n      \"payee\" => %{\"partyId\" => \"256771234567\", \"partyIdType\" => \"MSISDN\"},\n      \"status\" => \"SUCCESSFUL\"\n      }}","ref":"ExMtnMomo.html#disbursements_check_transaction_status/2-examples","title":"Examples - ExMtnMomo.disbursements_check_transaction_status/2","type":"function"},{"doc":"Provides functions for working with the MTN Mobile Money Sandbox environment.\n\nThe Sandbox module allows developers to:\n\n* Generate UUIDs for reference IDs\n* Create API users in the sandbox environment\n* Retrieve information about created users\n* Generate API keys for users\n\nThis module is primarily used during development and testing to set up the\nnecessary credentials for interacting with other MTN MoMo API endpoints.","ref":"ExMtnMomo.Sandbox.html","title":"ExMtnMomo.Sandbox","type":"module"},{"doc":"The Sandbox module uses the following configuration options:\n\n* `:base_url` - The base URL for the MTN Mobile Money API\n  * Default: `\"https://sandbox.momodeveloper.mtn.com\"`\n\n* `:sandbox_key` - The API key for sandbox operations\n  * This is typically your primary or secondary key provided by MTN\n  * Required for all sandbox operations\n\nThese options can be set in your `config.exs` file:\n\n```elixir\nconfig :ex_mtn_momo,\n  base_url: \"https://sandbox.momodeveloper.mtn.com\",\n  sandbox_key: \"your_primary_or_secondary_key\"\n```","ref":"ExMtnMomo.Sandbox.html#module-configuration-options","title":"Configuration Options - ExMtnMomo.Sandbox","type":"module"},{"doc":"Most functions in this module accept an `options` parameter that can be used to override\nconfiguration values at runtime. The following options are supported:\n\n* `:base_url` - Override the base URL for the API request\n* `:sandbox_key` - Override the sandbox key for authentication\n\nExample:\n\n```elixir\n# Override the sandbox key for a specific request\noptions = [sandbox_key: \"alternative_sandbox_key\"]\n\nuuid = ExMtnMomo.Sandbox.get_uuid4()\nExMtnMomo.Sandbox.create_api_user(uuid, \"https://webhook.site/callback\", options)\n```","ref":"ExMtnMomo.Sandbox.html#module-runtime-options","title":"Runtime Options - ExMtnMomo.Sandbox","type":"module"},{"doc":"```elixir\n# Generate a UUID for user creation\nuuid = ExMtnMomo.Sandbox.get_uuid4()\n\n# Create a user in the sandbox environment\n{:ok, _} = ExMtnMomo.Sandbox.create_api_user(uuid)\n\n# Get information about the created user\n{:ok, user_info} = ExMtnMomo.Sandbox.get_created_user(uuid)\n\n# Generate an API key for the user\n{:ok, %{\"apiKey\" => api_key}} = ExMtnMomo.Sandbox.get_api_key(uuid)\n```","ref":"ExMtnMomo.Sandbox.html#module-examples","title":"Examples - ExMtnMomo.Sandbox","type":"module"},{"doc":"Creates an API user in the sandbox environment.","ref":"ExMtnMomo.Sandbox.html#create_api_user/3","title":"ExMtnMomo.Sandbox.create_api_user/3","type":"function"},{"doc":"* `uuid4` - A UUID v4 string to use as the reference ID for the user\n* `callback_url` - URL to receive API callbacks (optional)\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Sandbox.html#create_api_user/3-parameters","title":"Parameters - ExMtnMomo.Sandbox.create_api_user/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Sandbox.html#create_api_user/3-options","title":"Options - ExMtnMomo.Sandbox.create_api_user/3","type":"function"},{"doc":"* `{:ok, \"User Created\"}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Sandbox.html#create_api_user/3-returns","title":"Returns - ExMtnMomo.Sandbox.create_api_user/3","type":"function"},{"doc":"iex> uuid = ExMtnMomo.Sandbox.get_uuid4()\n    iex> ExMtnMomo.Sandbox.create_api_user(uuid)\n    {:ok, \"User Created\"}","ref":"ExMtnMomo.Sandbox.html#create_api_user/3-examples","title":"Examples - ExMtnMomo.Sandbox.create_api_user/3","type":"function"},{"doc":"Generates and retrieves an API key for a user.","ref":"ExMtnMomo.Sandbox.html#get_api_key/2","title":"ExMtnMomo.Sandbox.get_api_key/2","type":"function"},{"doc":"* `uuid4` - The UUID of the user\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Sandbox.html#get_api_key/2-parameters","title":"Parameters - ExMtnMomo.Sandbox.get_api_key/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Sandbox.html#get_api_key/2-options","title":"Options - ExMtnMomo.Sandbox.get_api_key/2","type":"function"},{"doc":"* `{:ok, %{\"apiKey\" => api_key}}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Sandbox.html#get_api_key/2-returns","title":"Returns - ExMtnMomo.Sandbox.get_api_key/2","type":"function"},{"doc":"iex> uuid = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Sandbox.get_api_key(uuid)\n    {:ok, %{\"apiKey\" => \"a94d865a12e047319c6e673a15b48776\"}}","ref":"ExMtnMomo.Sandbox.html#get_api_key/2-examples","title":"Examples - ExMtnMomo.Sandbox.get_api_key/2","type":"function"},{"doc":"Retrieves information about a previously created API user.","ref":"ExMtnMomo.Sandbox.html#get_created_user/2","title":"ExMtnMomo.Sandbox.get_created_user/2","type":"function"},{"doc":"* `uuid4` - The UUID of the created user\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Sandbox.html#get_created_user/2-parameters","title":"Parameters - ExMtnMomo.Sandbox.get_created_user/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Sandbox.html#get_created_user/2-options","title":"Options - ExMtnMomo.Sandbox.get_created_user/2","type":"function"},{"doc":"* `{:ok, user_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Sandbox.html#get_created_user/2-returns","title":"Returns - ExMtnMomo.Sandbox.get_created_user/2","type":"function"},{"doc":"iex> uuid = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Sandbox.get_created_user(uuid)\n    {:ok, %{\"providerCallbackHost\" => \"https://webhook.site/2b823c34-90d7-4bf7-bd69-0f0559efcf3a\", ...}}","ref":"ExMtnMomo.Sandbox.html#get_created_user/2-examples","title":"Examples - ExMtnMomo.Sandbox.get_created_user/2","type":"function"},{"doc":"Generates a UUID v4 string.\n\nThis UUID can be used as a reference ID for API user creation and other operations.","ref":"ExMtnMomo.Sandbox.html#get_uuid4/0","title":"ExMtnMomo.Sandbox.get_uuid4/0","type":"function"},{"doc":"iex> ExMtnMomo.Sandbox.get_uuid4()\n    \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"","ref":"ExMtnMomo.Sandbox.html#get_uuid4/0-examples","title":"Examples - ExMtnMomo.Sandbox.get_uuid4/0","type":"function"},{"doc":"Provides functions for working with the MTN Mobile Money Collection API.\n\nThe Collection module allows developers to:\n\n* Create access tokens for authentication\n* Request payments from customers\n* Check the status of payment requests\n* Retrieve account balances\n* Get user information\n\nThis module is used for receiving payments from customers through\nthe MTN Mobile Money platform.","ref":"ExMtnMomo.Collection.html","title":"ExMtnMomo.Collection","type":"module"},{"doc":"The Collection module uses the following configuration options:","ref":"ExMtnMomo.Collection.html#module-configuration-options","title":"Configuration Options - ExMtnMomo.Collection","type":"module"},{"doc":"* `:base_url` - The base URL for the MTN Mobile Money API\n  * Default for sandbox: `\"https://sandbox.momodeveloper.mtn.com\"`\n  * Production: URL provided by MTN for your specific region\n\n* `:x_target_environment` - The target environment for API requests\n  * Options: `\"sandbox\"` for testing, or a specific production environment like `\"mtnzambia\"`\n  * Default: `\"sandbox\"`","ref":"ExMtnMomo.Collection.html#module-global-configuration","title":"Global Configuration - ExMtnMomo.Collection","type":"module"},{"doc":"Collection credentials are configured as a map under the `:collection` key:\n\n* `:collection.secondary_key` - Subscription key for the Collection API\n  * Used in the `Ocp-Apim-Subscription-Key` header\n  * Required for all Collection API operations\n\n* `:collection.primary_key` - Alternative subscription key\n  * Can be used as a backup if the secondary key fails\n\n* `:collection.user_id` - User ID for authentication\n  * Required for creating access tokens\n  * Used in the Basic Auth header\n\n* `:collection.api_key` - API key for authentication\n  * Required for creating access tokens\n  * Used in the Basic Auth header\n\nThese options should be set in your `config.exs` file:\n\n```elixir\nconfig :ex_mtn_momo,\n  base_url: \"https://sandbox.momodeveloper.mtn.com\",\n  x_target_environment: \"sandbox\",\n  collection: %{\n    secondary_key: \"your_secondary_key\",\n    primary_key: \"your_primary_key\",\n    user_id: \"your_user_id\",\n    api_key: \"your_api_key\"\n  }\n```","ref":"ExMtnMomo.Collection.html#module-collection-specific-configuration","title":"Collection-Specific Configuration - ExMtnMomo.Collection","type":"module"},{"doc":"Most functions in this module accept an `options` parameter that can be used to override\nconfiguration values at runtime. The following options are supported:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:primary_key` - Override the primary key to use for authentication\n* `:user_id` - Override the user ID for authentication\n* `:api_key` - Override the API key for authentication\n* `:x_target_environment` - Override the target environment\n\nExample:\n\n```elixir\n# Override the secondary key and target environment for a specific request\noptions = [\n  secondary_key: \"alternative_secondary_key\",\n  x_target_environment: \"production\"\n]\n\n{:ok, %{\"access_token\" => token}} = ExMtnMomo.Collection.create_access_token(options)\n```","ref":"ExMtnMomo.Collection.html#module-runtime-options","title":"Runtime Options - ExMtnMomo.Collection","type":"module"},{"doc":"```elixir\n# Get an access token for collections\n{:ok, %{\"access_token\" => token}} = ExMtnMomo.Collection.create_access_token()\n\n# Initiate a payment request\npayment_details = %{\n  \"amount\" => \"1000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"123456789\",\n  \"payer\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Payment for products\",\n  \"payeeNote\" => \"Payment received\"\n}\n\nreference_id = UUID.uuid4()\n{:ok, _} = ExMtnMomo.Collection.request_to_pay(payment_details, token, reference_id)\n\n# Check payment status\n{:ok, status} = ExMtnMomo.Collection.request_to_pay_transaction_status(reference_id, token)\n```","ref":"ExMtnMomo.Collection.html#module-examples","title":"Examples - ExMtnMomo.Collection","type":"module"},{"doc":"Retrieves basic information about a user.","ref":"ExMtnMomo.Collection.html#basic_user_info/3","title":"ExMtnMomo.Collection.basic_user_info/3","type":"function"},{"doc":"* `msisdn` - The mobile number of the user\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#basic_user_info/3-parameters","title":"Parameters - ExMtnMomo.Collection.basic_user_info/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#basic_user_info/3-options","title":"Options - ExMtnMomo.Collection.basic_user_info/3","type":"function"},{"doc":"* `{:ok, user_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#basic_user_info/3-returns","title":"Returns - ExMtnMomo.Collection.basic_user_info/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> msisdn = \"256771234567\"\n    iex> ExMtnMomo.Collection.basic_user_info(msisdn, token)\n    {:ok, %{\"name\" => \"John Doe\", ...}}","ref":"ExMtnMomo.Collection.html#basic_user_info/3-examples","title":"Examples - ExMtnMomo.Collection.basic_user_info/3","type":"function"},{"doc":"Creates an access token for collection operations.","ref":"ExMtnMomo.Collection.html#create_access_token/1","title":"ExMtnMomo.Collection.create_access_token/1","type":"function"},{"doc":"* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#create_access_token/1-parameters","title":"Parameters - ExMtnMomo.Collection.create_access_token/1","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Collection.html#create_access_token/1-options","title":"Options - ExMtnMomo.Collection.create_access_token/1","type":"function"},{"doc":"* `{:ok, token_details}` on success, where `token_details` includes the access_token\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#create_access_token/1-returns","title":"Returns - ExMtnMomo.Collection.create_access_token/1","type":"function"},{"doc":"iex> ExMtnMomo.Collection.create_access_token()\n    {:ok, %{\"access_token\" => \"eyJ0eXAi...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}","ref":"ExMtnMomo.Collection.html#create_access_token/1-examples","title":"Examples - ExMtnMomo.Collection.create_access_token/1","type":"function"},{"doc":"Creates an OAuth 2.0 token for collection operations.","ref":"ExMtnMomo.Collection.html#create_oauth_2_token/1","title":"ExMtnMomo.Collection.create_oauth_2_token/1","type":"function"},{"doc":"* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#create_oauth_2_token/1-parameters","title":"Parameters - ExMtnMomo.Collection.create_oauth_2_token/1","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Collection.html#create_oauth_2_token/1-options","title":"Options - ExMtnMomo.Collection.create_oauth_2_token/1","type":"function"},{"doc":"* `{:ok, token_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#create_oauth_2_token/1-returns","title":"Returns - ExMtnMomo.Collection.create_oauth_2_token/1","type":"function"},{"doc":"iex> ExMtnMomo.Collection.create_oauth_2_token()\n    {:ok, %{\"access_token\" => \"eyJ0eXAi...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}","ref":"ExMtnMomo.Collection.html#create_oauth_2_token/1-examples","title":"Examples - ExMtnMomo.Collection.create_oauth_2_token/1","type":"function"},{"doc":"Retrieves the account balance.","ref":"ExMtnMomo.Collection.html#get_account_balance/2","title":"ExMtnMomo.Collection.get_account_balance/2","type":"function"},{"doc":"* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_account_balance/2-parameters","title":"Parameters - ExMtnMomo.Collection.get_account_balance/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_account_balance/2-options","title":"Options - ExMtnMomo.Collection.get_account_balance/2","type":"function"},{"doc":"* `{:ok, balance_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_account_balance/2-returns","title":"Returns - ExMtnMomo.Collection.get_account_balance/2","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Collection.get_account_balance(token)\n    {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}","ref":"ExMtnMomo.Collection.html#get_account_balance/2-examples","title":"Examples - ExMtnMomo.Collection.get_account_balance/2","type":"function"},{"doc":"Retrieves the account balance for a specific currency.","ref":"ExMtnMomo.Collection.html#get_account_balance_in_specific_currency/3","title":"ExMtnMomo.Collection.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"* `currency` - Currency code (e.g., \"EUR\", \"USD\")\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_account_balance_in_specific_currency/3-parameters","title":"Parameters - ExMtnMomo.Collection.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_account_balance_in_specific_currency/3-options","title":"Options - ExMtnMomo.Collection.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"* `{:ok, balance_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_account_balance_in_specific_currency/3-returns","title":"Returns - ExMtnMomo.Collection.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Collection.get_account_balance_in_specific_currency(\"EUR\", token)\n    {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}","ref":"ExMtnMomo.Collection.html#get_account_balance_in_specific_currency/3-examples","title":"Examples - ExMtnMomo.Collection.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"Retrieves the status of an invoice.","ref":"ExMtnMomo.Collection.html#get_invoice_status/3","title":"ExMtnMomo.Collection.get_invoice_status/3","type":"function"},{"doc":"* `x_reference_id` - The reference ID of the invoice\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_invoice_status/3-parameters","title":"Parameters - ExMtnMomo.Collection.get_invoice_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_invoice_status/3-options","title":"Options - ExMtnMomo.Collection.get_invoice_status/3","type":"function"},{"doc":"* `{:ok, invoice_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_invoice_status/3-returns","title":"Returns - ExMtnMomo.Collection.get_invoice_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Collection.get_invoice_status(reference_id, token)\n    {:ok, %{\"status\" => \"PAID\", ...}}","ref":"ExMtnMomo.Collection.html#get_invoice_status/3-examples","title":"Examples - ExMtnMomo.Collection.get_invoice_status/3","type":"function"},{"doc":"Retrieves the status of a payment.","ref":"ExMtnMomo.Collection.html#get_payment_status/3","title":"ExMtnMomo.Collection.get_payment_status/3","type":"function"},{"doc":"* `x_reference_id` - The reference ID of the payment\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_payment_status/3-parameters","title":"Parameters - ExMtnMomo.Collection.get_payment_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_payment_status/3-options","title":"Options - ExMtnMomo.Collection.get_payment_status/3","type":"function"},{"doc":"* `{:ok, payment_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_payment_status/3-returns","title":"Returns - ExMtnMomo.Collection.get_payment_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Collection.get_payment_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Collection.html#get_payment_status/3-examples","title":"Examples - ExMtnMomo.Collection.get_payment_status/3","type":"function"},{"doc":"Retrieves the status of a pre-approval.","ref":"ExMtnMomo.Collection.html#get_pre_approval_status/3","title":"ExMtnMomo.Collection.get_pre_approval_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the pre-approval\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_pre_approval_status/3-parameters","title":"Parameters - ExMtnMomo.Collection.get_pre_approval_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_pre_approval_status/3-options","title":"Options - ExMtnMomo.Collection.get_pre_approval_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_pre_approval_status/3-returns","title":"Returns - ExMtnMomo.Collection.get_pre_approval_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Collection.get_pre_approval_status(reference_id, token)\n    {:ok, %{\"status\" => \"APPROVED\", ...}}","ref":"ExMtnMomo.Collection.html#get_pre_approval_status/3-examples","title":"Examples - ExMtnMomo.Collection.get_pre_approval_status/3","type":"function"},{"doc":"Retrieves user information with consent.","ref":"ExMtnMomo.Collection.html#get_user_info_with_consent/2","title":"ExMtnMomo.Collection.get_user_info_with_consent/2","type":"function"},{"doc":"* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#get_user_info_with_consent/2-parameters","title":"Parameters - ExMtnMomo.Collection.get_user_info_with_consent/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#get_user_info_with_consent/2-options","title":"Options - ExMtnMomo.Collection.get_user_info_with_consent/2","type":"function"},{"doc":"* `{:ok, user_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#get_user_info_with_consent/2-returns","title":"Returns - ExMtnMomo.Collection.get_user_info_with_consent/2","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Collection.get_user_info_with_consent(token)\n    {:ok, %{\"name\" => \"John Doe\", \"email\" => \"john.doe@example.com\", ...}}","ref":"ExMtnMomo.Collection.html#get_user_info_with_consent/2-examples","title":"Examples - ExMtnMomo.Collection.get_user_info_with_consent/2","type":"function"},{"doc":"Initiates a payment request to a customer.","ref":"ExMtnMomo.Collection.html#request_to_pay/4","title":"ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"* `attrs` - A map containing payment details\n* `access_token` - A valid access token\n* `uuid4` - A UUID v4 string as the reference ID (optional)\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#request_to_pay/4-parameters","title":"Parameters - ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"The `attrs` map should include the following keys:\n\n* `\"amount\"` - The payment amount\n* `\"currency\"` - The currency code (e.g., \"EUR\", \"USD\")\n* `\"externalId\"` - Your system's transaction ID\n* `\"payer\"` - A map containing payer information:\n  * `\"partyIdType\"` - The type of identifier (usually \"MSISDN\")\n  * `\"partyId\"` - The mobile number of the payer\n* `\"payerMessage\"` - Message shown to the payer\n* `\"payeeNote\"` - Note for the payee's records","ref":"ExMtnMomo.Collection.html#request_to_pay/4-payment-details","title":"Payment Details - ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#request_to_pay/4-options","title":"Options - ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#request_to_pay/4-returns","title":"Returns - ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> payment_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payer\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Payment for products\",\n    ...>   \"payeeNote\" => \"Payment received\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Collection.request_to_pay(payment_details, token, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Collection.html#request_to_pay/4-examples","title":"Examples - ExMtnMomo.Collection.request_to_pay/4","type":"function"},{"doc":"Checks the status of a payment request.","ref":"ExMtnMomo.Collection.html#request_to_pay_transaction_status/3","title":"ExMtnMomo.Collection.request_to_pay_transaction_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the payment request\n@spec get_account_balance_in_specific_currency(any(), any()) :: {:error, any()} | {:ok, any()}\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#request_to_pay_transaction_status/3-parameters","title":"Parameters - ExMtnMomo.Collection.request_to_pay_transaction_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#request_to_pay_transaction_status/3-options","title":"Options - ExMtnMomo.Collection.request_to_pay_transaction_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#request_to_pay_transaction_status/3-returns","title":"Returns - ExMtnMomo.Collection.request_to_pay_transaction_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Disbursements.request_to_pay_transaction_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Collection.html#request_to_pay_transaction_status/3-examples","title":"Examples - ExMtnMomo.Collection.request_to_pay_transaction_status/3","type":"function"},{"doc":"Checks the status of a withdrawal request.","ref":"ExMtnMomo.Collection.html#request_to_withdraw_transaction_status/3","title":"ExMtnMomo.Collection.request_to_withdraw_transaction_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the withdrawal request\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Collection.html#request_to_withdraw_transaction_status/3-parameters","title":"Parameters - ExMtnMomo.Collection.request_to_withdraw_transaction_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Collection.html#request_to_withdraw_transaction_status/3-options","title":"Options - ExMtnMomo.Collection.request_to_withdraw_transaction_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Collection.html#request_to_withdraw_transaction_status/3-returns","title":"Returns - ExMtnMomo.Collection.request_to_withdraw_transaction_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Collection.request_to_withdraw_transaction_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Collection.html#request_to_withdraw_transaction_status/3-examples","title":"Examples - ExMtnMomo.Collection.request_to_withdraw_transaction_status/3","type":"function"},{"doc":"Provides functions for working with the MTN Mobile Money Disbursements API.\n\nThe Disbursements module allows developers to:\n\n* Create access tokens for authentication\n* Send money to users (deposits)\n* Process refunds\n* Transfer money between accounts\n* Retrieve account balances\n* Check the status of transactions\n\nThis module is used for sending payments to customers through\nthe MTN Mobile Money platform.","ref":"ExMtnMomo.Disbursements.html","title":"ExMtnMomo.Disbursements","type":"module"},{"doc":"The Disbursements module uses the following configuration options:","ref":"ExMtnMomo.Disbursements.html#module-configuration-options","title":"Configuration Options - ExMtnMomo.Disbursements","type":"module"},{"doc":"* `:base_url` - The base URL for the MTN Mobile Money API\n  * Default for sandbox: `\"https://sandbox.momodeveloper.mtn.com\"`\n  * Production: URL provided by MTN for your specific region\n\n* `:x_target_environment` - The target environment for API requests\n  * Options: `\"sandbox\"` for testing, or a specific production environment like `\"mtnzambia\"`\n  * Default: `\"sandbox\"`","ref":"ExMtnMomo.Disbursements.html#module-global-configuration","title":"Global Configuration - ExMtnMomo.Disbursements","type":"module"},{"doc":"Disbursement credentials are configured as a map under the `:disbursement` key:\n\n* `:disbursement.secondary_key` - Subscription key for the Disbursements API\n  * Used in the `Ocp-Apim-Subscription-Key` header\n  * Required for all Disbursement API operations\n\n* `:disbursement.primary_key` - Alternative subscription key\n  * Can be used as a backup if the secondary key fails\n\n* `:disbursement.user_id` - User ID for authentication\n  * Required for creating access tokens\n  * Used in the Basic Auth header\n\n* `:disbursement.api_key` - API key for authentication\n  * Required for creating access tokens\n  * Used in the Basic Auth header\n\nThese options should be set in your `config.exs` file:\n\n```elixir\nconfig :ex_mtn_momo,\n  base_url: \"https://sandbox.momodeveloper.mtn.com\",\n  x_target_environment: \"sandbox\",\n  disbursement: %{\n    secondary_key: \"your_secondary_key\",\n    primary_key: \"your_primary_key\",\n    user_id: \"your_user_id\",\n    api_key: \"your_api_key\"\n  }\n```","ref":"ExMtnMomo.Disbursements.html#module-disbursement-specific-configuration","title":"Disbursement-Specific Configuration - ExMtnMomo.Disbursements","type":"module"},{"doc":"Most functions in this module accept an `options` parameter that can be used to override\nconfiguration values at runtime. The following options are supported:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:primary_key` - Override the primary key to use for authentication\n* `:user_id` - Override the user ID for authentication\n* `:api_key` - Override the API key for authentication\n* `:x_target_environment` - Override the target environment\n\nExample:\n\n```elixir\n# Override the secondary key and target environment for a specific request\noptions = [\n  secondary_key: \"alternative_secondary_key\",\n  x_target_environment: \"production\"\n]\n\n{:ok, %{\"access_token\" => token}} = ExMtnMomo.Disbursements.create_access_token(options)\n```","ref":"ExMtnMomo.Disbursements.html#module-runtime-options","title":"Runtime Options - ExMtnMomo.Disbursements","type":"module"},{"doc":"```elixir\n# Get an access token for disbursements\n{:ok, %{\"access_token\" => token}} = ExMtnMomo.Disbursements.create_access_token()\n\n# Initiate a deposit\ndeposit_details = %{\n  \"amount\" => \"1000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"123456789\",\n  \"payee\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Salary payment\",\n  \"payeeNote\" => \"Salary received\"\n}\n\nreference_id = UUID.uuid4()\n{:ok, _} = ExMtnMomo.Disbursements.deposit_v2(deposit_details, reference_id)\n\n# Check deposit status\n{:ok, status} = ExMtnMomo.Disbursements.get_deposit_status(reference_id, token)\n```","ref":"ExMtnMomo.Disbursements.html#module-examples","title":"Examples - ExMtnMomo.Disbursements","type":"module"},{"doc":"Authorizes a BC request.","ref":"ExMtnMomo.Disbursements.html#bc_authorize/1","title":"ExMtnMomo.Disbursements.bc_authorize/1","type":"function"},{"doc":"* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#bc_authorize/1-parameters","title":"Parameters - ExMtnMomo.Disbursements.bc_authorize/1","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#bc_authorize/1-options","title":"Options - ExMtnMomo.Disbursements.bc_authorize/1","type":"function"},{"doc":"* `{:ok, authorization_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#bc_authorize/1-returns","title":"Returns - ExMtnMomo.Disbursements.bc_authorize/1","type":"function"},{"doc":"iex> ExMtnMomo.Disbursements.bc_authorize()\n    {:ok, %{...}}","ref":"ExMtnMomo.Disbursements.html#bc_authorize/1-examples","title":"Examples - ExMtnMomo.Disbursements.bc_authorize/1","type":"function"},{"doc":"Creates an access token for disbursement operations.","ref":"ExMtnMomo.Disbursements.html#create_access_token/1","title":"ExMtnMomo.Disbursements.create_access_token/1","type":"function"},{"doc":"* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#create_access_token/1-parameters","title":"Parameters - ExMtnMomo.Disbursements.create_access_token/1","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#create_access_token/1-options","title":"Options - ExMtnMomo.Disbursements.create_access_token/1","type":"function"},{"doc":"* `{:ok, token_details}` on success, where `token_details` includes the access_token\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#create_access_token/1-returns","title":"Returns - ExMtnMomo.Disbursements.create_access_token/1","type":"function"},{"doc":"iex> ExMtnMomo.Disbursements.create_access_token()\n    {:ok, %{\"access_token\" => \"eyJ0eXAi...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}","ref":"ExMtnMomo.Disbursements.html#create_access_token/1-examples","title":"Examples - ExMtnMomo.Disbursements.create_access_token/1","type":"function"},{"doc":"Creates an OAuth 2.0 token for disbursement operations.","ref":"ExMtnMomo.Disbursements.html#create_oauth_2_token/1","title":"ExMtnMomo.Disbursements.create_oauth_2_token/1","type":"function"},{"doc":"* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#create_oauth_2_token/1-parameters","title":"Parameters - ExMtnMomo.Disbursements.create_oauth_2_token/1","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#create_oauth_2_token/1-options","title":"Options - ExMtnMomo.Disbursements.create_oauth_2_token/1","type":"function"},{"doc":"* `{:ok, token_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#create_oauth_2_token/1-returns","title":"Returns - ExMtnMomo.Disbursements.create_oauth_2_token/1","type":"function"},{"doc":"iex> ExMtnMomo.Disbursements.create_oauth_2_token()\n    {:ok, %{\"access_token\" => \"eyJ0eXAi...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}","ref":"ExMtnMomo.Disbursements.html#create_oauth_2_token/1-examples","title":"Examples - ExMtnMomo.Disbursements.create_oauth_2_token/1","type":"function"},{"doc":"Initiates a deposit using API version 1.0.","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3","title":"ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"* `attrs` - A map containing deposit details\n* `uuid4` - A UUID v4 string as the reference ID\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"The `attrs` map should include the following keys:\n\n* `\"amount\"` - The deposit amount\n* `\"currency\"` - The currency code (e.g., \"EUR\", \"USD\")\n* `\"externalId\"` - Your system's transaction ID\n* `\"payee\"` - A map containing payee information:\n  * `\"partyIdType\"` - The type of identifier (usually \"MSISDN\")\n  * `\"partyId\"` - The mobile number of the payee\n* `\"payerMessage\"` - Message shown to the payer\n* `\"payeeNote\"` - Note for the payee's records","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3-deposit-details","title":"Deposit Details - ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3-options","title":"Options - ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3-returns","title":"Returns - ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"iex> deposit_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payee\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Salary payment\",\n    ...>   \"payeeNote\" => \"Salary received\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Disbursements.deposit_v1(deposit_details, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Disbursements.html#deposit_v1/3-examples","title":"Examples - ExMtnMomo.Disbursements.deposit_v1/3","type":"function"},{"doc":"Initiates a deposit using API version 2.0.","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3","title":"ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"* `attrs` - A map containing deposit details\n* `uuid4` - A UUID v4 string as the reference ID\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"The `attrs` map should include the following keys:\n\n* `\"amount\"` - The deposit amount\n* `\"currency\"` - The currency code (e.g., \"EUR\", \"USD\")\n* `\"externalId\"` - Your system's transaction ID\n* `\"payee\"` - A map containing payee information:\n  * `\"partyIdType\"` - The type of identifier (usually \"MSISDN\")\n  * `\"partyId\"` - The mobile number of the payee\n* `\"payerMessage\"` - Message shown to the payer\n* `\"payeeNote\"` - Note for the payee's records","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3-deposit-details","title":"Deposit Details - ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3-options","title":"Options - ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3-returns","title":"Returns - ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"iex> deposit_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payee\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Salary payment\",\n    ...>   \"payeeNote\" => \"Salary received\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Disbursements.deposit_v2(deposit_details, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Disbursements.html#deposit_v2/3-examples","title":"Examples - ExMtnMomo.Disbursements.deposit_v2/3","type":"function"},{"doc":"Retrieves the account balance for disbursements.","ref":"ExMtnMomo.Disbursements.html#get_account_balance/2","title":"ExMtnMomo.Disbursements.get_account_balance/2","type":"function"},{"doc":"* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_account_balance/2-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_account_balance/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_account_balance/2-options","title":"Options - ExMtnMomo.Disbursements.get_account_balance/2","type":"function"},{"doc":"* `{:ok, balance_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_account_balance/2-returns","title":"Returns - ExMtnMomo.Disbursements.get_account_balance/2","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Disbursements.get_account_balance(token)\n    {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}","ref":"ExMtnMomo.Disbursements.html#get_account_balance/2-examples","title":"Examples - ExMtnMomo.Disbursements.get_account_balance/2","type":"function"},{"doc":"Retrieves the account balance for a specific currency for disbursements.","ref":"ExMtnMomo.Disbursements.html#get_account_balance_in_specific_currency/3","title":"ExMtnMomo.Disbursements.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"* `currency` - Currency code (e.g., \"EUR\", \"USD\")\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_account_balance_in_specific_currency/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_account_balance_in_specific_currency/3-options","title":"Options - ExMtnMomo.Disbursements.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"* `{:ok, balance_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_account_balance_in_specific_currency/3-returns","title":"Returns - ExMtnMomo.Disbursements.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Disbursements.get_account_balance_in_specific_currency(\"EUR\", token)\n    {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}","ref":"ExMtnMomo.Disbursements.html#get_account_balance_in_specific_currency/3-examples","title":"Examples - ExMtnMomo.Disbursements.get_account_balance_in_specific_currency/3","type":"function"},{"doc":"Retrieves the status of a deposit.","ref":"ExMtnMomo.Disbursements.html#get_deposit_status/3","title":"ExMtnMomo.Disbursements.get_deposit_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the deposit\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_deposit_status/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_deposit_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_deposit_status/3-options","title":"Options - ExMtnMomo.Disbursements.get_deposit_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_deposit_status/3-returns","title":"Returns - ExMtnMomo.Disbursements.get_deposit_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Disbursements.get_deposit_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Disbursements.html#get_deposit_status/3-examples","title":"Examples - ExMtnMomo.Disbursements.get_deposit_status/3","type":"function"},{"doc":"Retrieves the status of a refund.","ref":"ExMtnMomo.Disbursements.html#get_refund_status/3","title":"ExMtnMomo.Disbursements.get_refund_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the refund\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_refund_status/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_refund_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_refund_status/3-options","title":"Options - ExMtnMomo.Disbursements.get_refund_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_refund_status/3-returns","title":"Returns - ExMtnMomo.Disbursements.get_refund_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Disbursements.get_refund_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Disbursements.html#get_refund_status/3-examples","title":"Examples - ExMtnMomo.Disbursements.get_refund_status/3","type":"function"},{"doc":"Retrieves the status of a transfer.","ref":"ExMtnMomo.Disbursements.html#get_transfer_status/3","title":"ExMtnMomo.Disbursements.get_transfer_status/3","type":"function"},{"doc":"* `reference_id` - The reference ID of the transfer\n* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_transfer_status/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_transfer_status/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_transfer_status/3-options","title":"Options - ExMtnMomo.Disbursements.get_transfer_status/3","type":"function"},{"doc":"* `{:ok, status_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_transfer_status/3-returns","title":"Returns - ExMtnMomo.Disbursements.get_transfer_status/3","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> reference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\"\n    iex> ExMtnMomo.Disbursements.get_transfer_status(reference_id, token)\n    {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}","ref":"ExMtnMomo.Disbursements.html#get_transfer_status/3-examples","title":"Examples - ExMtnMomo.Disbursements.get_transfer_status/3","type":"function"},{"doc":"Retrieves user information with consent for disbursements.","ref":"ExMtnMomo.Disbursements.html#get_user_info_with_consent/2","title":"ExMtnMomo.Disbursements.get_user_info_with_consent/2","type":"function"},{"doc":"* `access_token` - A valid access token\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#get_user_info_with_consent/2-parameters","title":"Parameters - ExMtnMomo.Disbursements.get_user_info_with_consent/2","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication\n* `:x_target_environment` - Override the target environment","ref":"ExMtnMomo.Disbursements.html#get_user_info_with_consent/2-options","title":"Options - ExMtnMomo.Disbursements.get_user_info_with_consent/2","type":"function"},{"doc":"* `{:ok, user_details}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#get_user_info_with_consent/2-returns","title":"Returns - ExMtnMomo.Disbursements.get_user_info_with_consent/2","type":"function"},{"doc":"iex> token = \"eyJ0eXAi...\"\n    iex> ExMtnMomo.Disbursements.get_user_info_with_consent(token)\n    {:ok, %{\"name\" => \"John Doe\", \"email\" => \"john.doe@example.com\", ...}}","ref":"ExMtnMomo.Disbursements.html#get_user_info_with_consent/2-examples","title":"Examples - ExMtnMomo.Disbursements.get_user_info_with_consent/2","type":"function"},{"doc":"Initiates a refund using API version 1.0.","ref":"ExMtnMomo.Disbursements.html#refund_v1/3","title":"ExMtnMomo.Disbursements.refund_v1/3","type":"function"},{"doc":"* `attrs` - A map containing refund details\n* `uuid4` - A UUID v4 string as the reference ID\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#refund_v1/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.refund_v1/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#refund_v1/3-options","title":"Options - ExMtnMomo.Disbursements.refund_v1/3","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#refund_v1/3-returns","title":"Returns - ExMtnMomo.Disbursements.refund_v1/3","type":"function"},{"doc":"iex> refund_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payerMessage\" => \"Refund for order cancellation\",\n    ...>   \"payeeNote\" => \"Refund processed\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Disbursements.refund_v1(refund_details, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Disbursements.html#refund_v1/3-examples","title":"Examples - ExMtnMomo.Disbursements.refund_v1/3","type":"function"},{"doc":"Initiates a refund using API version 2.0.","ref":"ExMtnMomo.Disbursements.html#refund_v2/3","title":"ExMtnMomo.Disbursements.refund_v2/3","type":"function"},{"doc":"* `attrs` - A map containing refund details\n* `uuid4` - A UUID v4 string as the reference ID\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#refund_v2/3-parameters","title":"Parameters - ExMtnMomo.Disbursements.refund_v2/3","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#refund_v2/3-options","title":"Options - ExMtnMomo.Disbursements.refund_v2/3","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#refund_v2/3-returns","title":"Returns - ExMtnMomo.Disbursements.refund_v2/3","type":"function"},{"doc":"iex> refund_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payerMessage\" => \"Refund for order cancellation\",\n    ...>   \"payeeNote\" => \"Refund processed\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Disbursements.refund_v2(refund_details, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Disbursements.html#refund_v2/3-examples","title":"Examples - ExMtnMomo.Disbursements.refund_v2/3","type":"function"},{"doc":"Initiates a transfer.","ref":"ExMtnMomo.Disbursements.html#transfer/4","title":"ExMtnMomo.Disbursements.transfer/4","type":"function"},{"doc":"* `attrs` - A map containing transfer details\n* `uuid4` - A UUID v4 string as the reference ID\n* `options` - Additional configuration options (optional)","ref":"ExMtnMomo.Disbursements.html#transfer/4-parameters","title":"Parameters - ExMtnMomo.Disbursements.transfer/4","type":"function"},{"doc":"The `options` parameter can include the following keys:\n\n* `:base_url` - Override the base URL for the API request\n* `:secondary_key` - Override the secondary key to use for authentication","ref":"ExMtnMomo.Disbursements.html#transfer/4-options","title":"Options - ExMtnMomo.Disbursements.transfer/4","type":"function"},{"doc":"* `{:ok, response}` on success\n* `{:error, reason}` on failure","ref":"ExMtnMomo.Disbursements.html#transfer/4-returns","title":"Returns - ExMtnMomo.Disbursements.transfer/4","type":"function"},{"doc":"iex> transfer_details = %{\n    ...>   \"amount\" => \"1000\",\n    ...>   \"currency\" => \"EUR\",\n    ...>   \"externalId\" => \"123456789\",\n    ...>   \"payee\" => %{\n    ...>     \"partyIdType\" => \"MSISDN\",\n    ...>     \"partyId\" => \"256771234567\"\n    ...>   },\n    ...>   \"payerMessage\" => \"Transfer payment\",\n    ...>   \"payeeNote\" => \"Transfer received\"\n    ...> }\n    iex> reference_id = UUID.uuid4()\n    iex> ExMtnMomo.Disbursements.transfer(transfer_details, reference_id)\n    {:ok, %{}}","ref":"ExMtnMomo.Disbursements.html#transfer/4-examples","title":"Examples - ExMtnMomo.Disbursements.transfer/4","type":"function"},{"doc":"# ExMtnMomo\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_mtn_momo.svg)](https://hex.pm/packages/ex_mtn_momo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/ex_mtn_momo)\n[![License](https://img.shields.io/hexpm/l/ex_mtn_momo.svg)](https://github.com/your-username/ex_mtn_momo/blob/master/LICENSE)\n\nA robust Elixir client library for the MTN Mobile Money API, providing a simple and elegant interface for integrating with MTN's payment services.","ref":"readme.html","title":"ExMtnMomo","type":"extras"},{"doc":"- 📱 **Complete API Coverage** - Support for Collections, Disbursements, and Sandbox APIs\n- 🔄 **Webhook Integration** - Easy processing of MTN MoMo callbacks\n- 🔒 **Secure Authentication** - Seamless handling of OAuth tokens\n- ⚙️ **Flexible Configuration** - Environment-specific settings\n- 🧪 **Sandbox Testing** - Development environment support\n- 🛠️ **Comprehensive Tooling** - Error handling, response parsing, and more","ref":"readme.html#features","title":"Features - ExMtnMomo","type":"extras"},{"doc":"Add `ex_mtn_momo` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_mtn_momo, \"~> 0.1.2\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - ExMtnMomo","type":"extras"},{"doc":"Add your MTN MoMo API credentials to your `config.exs` file:\n\n```elixir\nconfig :ex_mtn_momo,\n  base_url: \"https://sandbox.momodeveloper.mtn.com\",\n  x_target_environment: \"sandbox\", # Options: \"sandbox\", \"mtnzambia\", etc.\n  sandbox_key: \"your_secondary_key or your_primary_key\",\n  \n  # Disbursement credentials\n  disbursement: %{\n    secondary_key: \"542809304c684ef1ad69d0abd0365a27\",\n    primary_key: \"c5fd5b948d48486182bacfec52b81146\",\n    user_id: \"ed59bb21-d650-43cc-87b5-81db171c22bf\",\n    api_key: \"379d8f976c874bdd8fe2a66e72e14ca8\"\n  },\n  \n  # Collection credentials\n  collection: %{\n    secondary_key: \"68f9275fb30547a9b9b592872317d88c\",\n    primary_key: \"e39426048d6a4fff91f40bbb1e67283b\",\n    user_id: \"75117b89-c4b5-4c44-b2ad-676cfae53be6\",\n    api_key: \"79a148215e1e4fb48209d317d58a5c71\"\n  }\n```","ref":"readme.html#configuration","title":"Configuration - ExMtnMomo","type":"extras"},{"doc":"ExMtnMomo provides high-level convenience functions for common operations:","ref":"readme.html#quick-start-guide","title":"Quick Start Guide - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a sandbox user with all required credentials in one call\n{:ok, user_details} = ExMtnMomo.create_sandbox_user(\"https://webhook.site/your-id\")\n# => {:ok, %{\n#      \"api_key\" => \"6418abf0507b4829a7ded11ca8f67cd7\",\n#      \"providerCallbackHost\" => \"https://webhook.site/your-id\",\n#      \"targetEnvironment\" => \"sandbox\",\n#      \"user_id\" => \"3d6df852-7be6-4870-be57-b784446a885c\"\n#    }}\n```","ref":"readme.html#create-a-sandbox-user","title":"Create a Sandbox User - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a payment request with a single function call\npayment_details = %{\n  \"amount\" => \"5000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"123456789\",\n  \"payer\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Payment for order #12345\",\n  \"payeeNote\" => \"Customer payment received\"\n}\n\n# Request payment (token creation handled automatically)\n{:ok, result} = ExMtnMomo.collect_funds(payment_details)\n# => {:ok, %{\n#      \"x_reference_id\" => \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\",\n#      \"status\" => \"pending\",\n#      \"message\" => \"Request to pay has been sent\"\n#    }}\n\n# Check payment status\n{:ok, status} = ExMtnMomo.collections_check_transaction_status(result[\"x_reference_id\"])\n# => {:ok, \n#      %{\n#        \"amount\" => \"5000\",\n#        \"currency\" => \"EUR\",\n#        \"externalId\" => \"123456789\",\n#        \"financialTransactionId\" => \"23503452\",\n#        \"payer\" => %{\n#          \"partyIdType\" => \"MSISDN\",\n#          \"partyId\" => \"256771234567\"\n#        },\n#        \"status\" => \"SUCCESSFUL\"\n#      }\n#    }\n```","ref":"readme.html#collect-funds-request-payment-from-customer","title":"Collect Funds (Request Payment from Customer) - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a disbursement with a single function call\ndisbursement_details = %{\n  \"amount\" => \"1000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"987654321\",\n  \"payee\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Salary payment\",\n  \"payeeNote\" => \"Monthly salary\"\n}\n\n# Send the disbursement (token creation handled automatically)\n{:ok, _} = ExMtnMomo.disburse_funds(disbursement_details)\n# => {:ok, %{}}\n\n# Check disbursement status (requires reference_id from the disburse_funds call)\nreference_id = \"f1bfc995-8dbe-4afb-aa82-a8c75a37edf6\" # from the disburse_funds result\n{:ok, status} = ExMtnMomo.disbursements_check_transaction_status(reference_id)\n# => {:ok, \n#      %{\n#        \"amount\" => \"1000\",\n#        \"currency\" => \"EUR\",\n#        \"externalId\" => \"987654321\",\n#        \"financialTransactionId\" => \"45678901\",\n#        \"payee\" => %{\n#          \"partyIdType\" => \"MSISDN\",\n#          \"partyId\" => \"256771234567\"\n#        },\n#        \"status\" => \"SUCCESSFUL\"\n#      }\n#    }\n```","ref":"readme.html#disburse-funds-send-payment-to-customer","title":"Disburse Funds (Send Payment to Customer) - ExMtnMomo","type":"extras"},{"doc":"ExMtnMomo is organized into three main modules:\n\n- `ExMtnMomo.Sandbox` - Functions for setting up and testing in the sandbox environment\n- `ExMtnMomo.Collection` - Functions for receiving payments from customers\n- `ExMtnMomo.Disbursements` - Functions for sending payments to customers","ref":"readme.html#api-overview","title":"API Overview - ExMtnMomo","type":"extras"},{"doc":"The Sandbox module allows you to create and manage API users for testing purposes.","ref":"readme.html#sandbox-api","title":"Sandbox API - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Generate a UUID for the new user\nuuid = ExMtnMomo.Sandbox.get_uuid4()\n# => \"f8c7a6e5-d4b3-2c1a-0f9e-8d7c6b5a4e3d\"\n\n# Create an API user with a callback URL\n{:ok, _} = ExMtnMomo.Sandbox.create_api_user(\n  uuid,\n  \"https://webhook.site/your-webhook-id\"\n)\n# => {:ok, \"User Created\"}\n\n# Retrieve user details\n{:ok, user_info} = ExMtnMomo.Sandbox.get_created_user(uuid)\n# => {:ok, %{\"providerCallbackHost\" => \"https://webhook.site/your-webhook-id\"}}\n\n# Generate an API key for the user\n{:ok, %{\"apiKey\" => api_key}} = ExMtnMomo.Sandbox.get_api_key(uuid)\n# => {:ok, %{\"apiKey\" => \"a94d865a12e047319c6e673a15b48776\"}}\n```","ref":"readme.html#creating-a-user","title":"Creating a User - ExMtnMomo","type":"extras"},{"doc":"The Collection API facilitates receiving payments from mobile money users.","ref":"readme.html#collection-api","title":"Collection API - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create an access token for collection operations\n{:ok, token_info} = ExMtnMomo.Collection.create_access_token()\n# => {:ok, %{\"access_token\" => \"eyJ0eXAiOiJKV1QiLCJhbGciOiJSMjU2In0...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}\n\n# Extract the access token\naccess_token = token_info[\"access_token\"]\n```","ref":"readme.html#authentication","title":"Authentication - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a payment request\npayment_details = %{\n  \"amount\" => \"5000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"123456789\",\n  \"payer\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Payment for order #12345\",\n  \"payeeNote\" => \"Customer payment received\"\n}\n\n# Generate a reference ID\nreference_id = UUID.uuid4()\n\n# Submit the payment request\n{:ok, _} = ExMtnMomo.Collection.request_to_pay(payment_details, access_token, reference_id)\n# => {:ok, %{}}\n\n# Check payment status\n{:ok, status} = ExMtnMomo.Collection.request_to_pay_transaction_status(reference_id, access_token)\n# => {:ok, \n#      %{\n#        \"amount\" => \"5000\",\n#        \"currency\" => \"EUR\",\n#        \"externalId\" => \"123456789\",\n#        \"financialTransactionId\" => \"23503452\",\n#        \"payer\" => %{\n#          \"partyIdType\" => \"MSISDN\",\n#          \"partyId\" => \"256771234567\"\n#        },\n#        \"status\" => \"SUCCESSFUL\"\n#      }\n#    }\n```","ref":"readme.html#request-to-pay","title":"Request to Pay - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Get account balance\n{:ok, balance} = ExMtnMomo.Collection.get_account_balance(access_token)\n# => {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}\n\n# Get balance in a specific currency\n{:ok, balance_eur} = ExMtnMomo.Collection.get_account_balance_in_specific_currency(\"EUR\", access_token)\n# => {:ok, %{\"availableBalance\" => \"15000\", \"currency\" => \"EUR\"}}\n\n# Get user information\n{:ok, user_info} = ExMtnMomo.Collection.basic_user_info(\"256771234567\", access_token)\n# => {:ok, %{\"name\" => \"John Doe\", ...}}\n```","ref":"readme.html#account-operations","title":"Account Operations - ExMtnMomo","type":"extras"},{"doc":"The Disbursement API allows you to send money to mobile money users.","ref":"readme.html#disbursement-api","title":"Disbursement API - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create an access token for disbursement operations\n{:ok, token_info} = ExMtnMomo.Disbursements.create_access_token()\n# => {:ok, %{\"access_token\" => \"eyJ0eXAiOiJKV1QiLCJhbGciOiJSMjU2In0...\", \"expires_in\" => 3600, \"token_type\" => \"Bearer\"}}\n\n# Extract the access token\naccess_token = token_info[\"access_token\"]\n```","ref":"readme.html#authentication","title":"Authentication - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a deposit transaction\ndeposit_details = %{\n  \"amount\" => \"10000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"987654321\",\n  \"payee\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Salary payment\",\n  \"payeeNote\" => \"Monthly salary\"\n}\n\n# Generate a reference ID\nreference_id = UUID.uuid4()\n\n# Execute the deposit (using API v2)\n{:ok, _} = ExMtnMomo.Disbursements.deposit_v2(deposit_details, reference_id)\n# => {:ok, %{}}\n\n# Check deposit status\n{:ok, status} = ExMtnMomo.Disbursements.get_deposit_status(reference_id, access_token)\n# => {:ok, \n#      %{\n#        \"amount\" => \"10000\",\n#        \"currency\" => \"EUR\",\n#        \"externalId\" => \"987654321\",\n#        \"financialTransactionId\" => \"45678901\",\n#        \"payee\" => %{\n#          \"partyIdType\" => \"MSISDN\",\n#          \"partyId\" => \"256771234567\"\n#        },\n#        \"status\" => \"SUCCESSFUL\"\n#      }\n#    }\n```","ref":"readme.html#deposit","title":"Deposit - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a refund transaction\nrefund_details = %{\n  \"amount\" => \"5000\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"ref987654321\",\n  \"payerMessage\" => \"Order cancellation refund\",\n  \"payeeNote\" => \"Refund for order #12345\"\n}\n\n# Generate a reference ID\nreference_id = UUID.uuid4()\n\n# Execute the refund (using API v2)\n{:ok, _} = ExMtnMomo.Disbursements.refund_v2(refund_details, reference_id)\n# => {:ok, %{}}\n\n# Check refund status\n{:ok, status} = ExMtnMomo.Disbursements.get_refund_status(reference_id, access_token)\n# => {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}\n```","ref":"readme.html#refund","title":"Refund - ExMtnMomo","type":"extras"},{"doc":"```elixir\n# Create a transfer transaction\ntransfer_details = %{\n  \"amount\" => \"2500\",\n  \"currency\" => \"EUR\",\n  \"externalId\" => \"transfer123456\",\n  \"payee\" => %{\n    \"partyIdType\" => \"MSISDN\",\n    \"partyId\" => \"256771234567\"\n  },\n  \"payerMessage\" => \"Transfer to your account\",\n  \"payeeNote\" => \"Funds transfer\"\n}\n\n# Generate a reference ID\nreference_id = UUID.uuid4()\n\n# Execute the transfer\n{:ok, _} = ExMtnMomo.Disbursements.transfer(transfer_details, reference_id)\n# => {:ok, %{}}\n\n# Check transfer status\n{:ok, status} = ExMtnMomo.Disbursements.get_transfer_status(reference_id, access_token)\n# => {:ok, %{\"status\" => \"SUCCESSFUL\", ...}}\n```","ref":"readme.html#transfer","title":"Transfer - ExMtnMomo","type":"extras"},{"doc":"","ref":"readme.html#complete-function-list","title":"Complete Function List - ExMtnMomo","type":"extras"},{"doc":"| Function | Description |\n|----------|-------------|\n| `create_sandbox_user/2` | Creates a sandbox user with all required credentials in one call |\n| `collect_funds/3` | Initiates a payment collection request (token creation handled automatically) |\n| `collections_check_transaction_status/2` | Checks the status of a payment collection request |\n| `disburse_funds/3` | Initiates a funds disbursement (token creation handled automatically) |\n| `disbursements_check_transaction_status/2` | Checks the status of a disbursement transaction |","ref":"readme.html#high-level-functions-exmtnmomo","title":"High-Level Functions (ExMtnMomo) - ExMtnMomo","type":"extras"},{"doc":"| Function | Description |\n|----------|-------------|\n| `get_uuid4/0` | Generates a UUID v4 string |\n| `create_api_user/3` | Creates an API user in the sandbox environment |\n| `get_created_user/2` | Retrieves information about a created user |\n| `get_api_key/2` | Generates and retrieves an API key for a user |","ref":"readme.html#sandbox-module","title":"Sandbox Module - ExMtnMomo","type":"extras"},{"doc":"| Function | Description |\n|----------|-------------|\n| `create_access_token/1` | Creates an access token for collection operations |\n| `create_oauth_2_token/1` | Creates an OAuth 2.0 token for collection operations |\n| `request_to_pay/4` | Initiates a payment request to a customer |\n| `request_to_pay_transaction_status/3` | Checks the status of a payment request |\n| `get_account_balance_in_specific_currency/3` | Retrieves account balance for a specific currency |\n| `get_account_balance/2` | Retrieves the overall account balance |\n| `get_invoice_status/3` | Retrieves the status of an invoice |\n| `request_to_withdraw_transaction_status/3` | Checks the status of a withdrawal request |\n| `basic_user_info/3` | Retrieves basic information about a user |\n| `get_payment_status/3` | Retrieves the status of a payment |\n| `get_pre_approval_status/3` | Retrieves the status of a pre-approval |\n| `get_user_info_with_consent/2` | Retrieves user information with consent |","ref":"readme.html#collection-module","title":"Collection Module - ExMtnMomo","type":"extras"},{"doc":"| Function | Description |\n|----------|-------------|\n| `bc_authorize/1` | Authorizes a BC request |\n| `create_access_token/1` | Creates an access token for disbursement operations |\n| `create_oauth_2_token/1` | Creates an OAuth 2.0 token for disbursement operations |\n| `deposit_v1/3` | Initiates a deposit using API version 1.0 |\n| `deposit_v2/3` | Initiates a deposit using API version 2.0 |\n| `refund_v1/3` | Initiates a refund using API version 1.0 |\n| `refund_v2/3` | Initiates a refund using API version 2.0 |\n| `transfer/3` | Initiates a transfer |\n| `get_account_balance/2` | Retrieves the account balance for disbursements |\n| `get_account_balance_in_specific_currency/3` | Retrieves account balance for a specific currency |\n| `get_deposit_status/3` | Retrieves the status of a deposit |\n| `get_refund_status/3` | Retrieves the status of a refund |\n| `get_transfer_status/3` | Retrieves the status of a transfer |\n| `get_user_info_with_consent/2` | Retrieves user information with consent for disbursements |","ref":"readme.html#disbursements-module","title":"Disbursements Module - ExMtnMomo","type":"extras"},{"doc":"All API calls return either `{:ok, result}` or `{:error, reason}`. This allows for clean error handling with pattern matching:\n\n```elixir\ncase ExMtnMomo.collect_funds(payment_details) do\n  {:ok, %{\"x_reference_id\" => reference_id}} ->\n    # Handle successful payment request\n    Logger.info(\"Payment request successful: #{reference_id}\")\n    {:ok, reference_id}\n    \n  {:error, %{\"code\" => code, \"message\" => message}} ->\n    # Handle API error with code and message\n    Logger.error(\"Payment request failed: #{code} - #{message}\")\n    {:error, :payment_request_failed}\n    \n  {:error, reason} ->\n    # Handle other errors\n    Logger.error(\"Payment request error: #{inspect(reason)}\")\n    {:error, :unknown_error}\nend\n```","ref":"readme.html#error-handling","title":"Error Handling - ExMtnMomo","type":"extras"},{"doc":"To run the tests:\n\n```bash\nmix test\n```","ref":"readme.html#testing","title":"Testing - ExMtnMomo","type":"extras"},{"doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add some amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request","ref":"readme.html#contributing","title":"Contributing - ExMtnMomo","type":"extras"},{"doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license","title":"License - ExMtnMomo","type":"extras"},{"doc":"- MTN Mobile Money API documentation\n- Elixir community for the excellent HTTP and JSON libraries","ref":"readme.html#acknowledgments","title":"Acknowledgments - ExMtnMomo","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2025 James Njovu\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.3"},"proglang":"elixir"}